@@ -29,6 +29,12 @@
 #  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
-void test_ngtcp2_window_filter_update(void);
+#define MUNIT_ENABLE_ASSERT_ALIASES
+
+#include "munit.h"
+
+extern const MunitSuite window_filter_suite;
+
+munit_void_test_decl(test_ngtcp2_window_filter_update);
 
 #endif /* NGTCP2_WINDOW_FILTER_TEST_H */
